@@ -25,6 +25,7 @@ import stat    # for ST_MODE
 import string  # for atof()
 import copy    # for deepcopy()
 import time    # for time()
+import getopt
 
 from svntest import Failure
 from svntest import Skip
@@ -110,7 +111,7 @@ if windows == 1:
   test_area_url = string.replace(test_area_url, '\\', '/')
 
 # Global variable indicating the FS type for repository creations.
-fs_type = "bdb"
+fs_type = None
 
 # Where we want all the repositories and working copies to live.
 # Each test will have its own!
@@ -319,11 +320,12 @@ def create_repos(path):
   if not(os.path.exists(path)):
     os.makedirs(path) # this creates all the intermediate dirs, if neccessary
 
-  stdout, stderr = run_command(svnadmin_binary, 1, 0, "create", path,
-                               "--bdb-txn-nosync", "--fs-type", fs_type)
+  opts = ("--bdb-txn-nosync",)
+  if fs_type is not None:
+    opts += ("--fs-type=" + fs_type,)
+  stdout, stderr = run_command(svnadmin_binary, 1, 0, "create", path, *opts)
 
-  # Skip tests if we can't create the repository (most likely, because
-  # Subversion was built without BDB and this is a default test run).
+  # Skip tests if we can't create the repository.
   for line in stderr:
     if line.find('Unknown FS type') != -1:
       raise Skip
@@ -515,7 +517,8 @@ def _internal_run_tests(test_list, testnum=None):
 
   if testnum is None:
     for n in range(1, len(test_list)):
-      if run_one_test(n, test_list):
+      # 1 is the only return code that indicates actual test failure.
+      if run_one_test(n, test_list) == 1:
         exit_code = 1
   else:
     exit_code = run_one_test(testnum, test_list)
@@ -551,11 +554,13 @@ def run_tests(test_list):
   # log message will fail rather than invoke an editor.
   os.environ['SVN_EDITOR'] = ''
 
-  url_re = re.compile('^(?:--url|BASE_URL)=(.+)')
-  fstype_re = re.compile('^--fs-type=(.+)')
-
-  for arg in sys.argv:
+  try:
+    opts, args = getopt.getopt(sys.argv[1:], 'v',
+                               ['url=', 'fs-type=', 'verbose', 'cleanup'])
+  except getopt.GetoptError:
+    args = []
 
+  for arg in args:
     if arg == "list":
       print "Test #  Mode   Test Description"
       print "------  -----  ----------------"
@@ -567,34 +572,27 @@ def run_tests(test_list):
       # done. just exit with success.
       sys.exit(0)
 
-    elif arg == "--url":
-      index = sys.argv.index(arg)
-      test_area_url = sys.argv[index + 1]
+    if arg.startswith('BASE_URL='):
+      test_area_url = arg[9:]
+    else:
+      try:
+        testnum = int(arg)
+      except ValueError:
+        pass
 
-    elif arg == "--fs-type":
-      index = sys.argv.index(arg)
-      fs_type = sys.argv[index + 1]
+  for opt, val in opts:
+    if opt == "--url":
+      test_area_url = val
 
-    elif arg == "-v" or arg == "--verbose":
+    elif opt == "--fs-type":
+      fs_type = val
+
+    elif opt == "-v" or opt == "--verbose":
       verbose_mode = 1
 
-    elif arg == "--cleanup":
+    elif opt == "--cleanup":
       cleanup_mode = 1
 
-    else:
-      match = url_re.search(arg)
-      if match:
-        test_area_url = match.group(1)
-      match = fstype_re.search(arg)
-      if match:
-        fs_type = match.group(1)
-
-      else:
-        try:
-          testnum = int(arg)
-        except ValueError:
-          pass
-
   exit_code = _internal_run_tests(test_list, testnum)
 
   # remove all scratchwork: the 'pristine' repository, greek tree, etc.
